@@ -1,7 +1,7 @@
 package Sah::Examples;
 
-our $DATE = '2017-03-09'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-05-22'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 1;
 # ABSTRACT: Example Sah schemas
@@ -18,7 +18,7 @@ Sah::Examples - Example Sah schemas
 
 =head1 VERSION
 
-This document describes version 0.04 of Sah::Examples (from Perl distribution Sah-Examples), released on 2017-03-09.
+This document describes version 0.05 of Sah::Examples (from Perl distribution Sah-Examples), released on 2017-05-22.
 
 =head1 DESCRIPTION
 
@@ -31,9 +31,9 @@ This POD also contains examples of schemas.
 
 The examples are written in JSON with Javascript-style comments (C<// comment>).
 
-=head2 Simple
+=head2 Various simple examples
 
- # integer, optional
+ // integer, optional
  "int"
 
  // required integer
@@ -66,6 +66,32 @@ The examples are written in JSON with Javascript-style comments (C<// comment>).
  // a byte that's *in*divisible by 3
  ["byte", {"!div_by": 3}]
 
+=head2 Type: array
+
+ // minimum number of elements
+ ["array*", {"min_len": 1}]
+
+ // maximum number of elements
+ ["array*", {"max_len": 10}]
+
+=head2 Type: hash
+
+ // hash must only contain keys a, b, or c
+ // Valid: {}, {"a": 1}, {"a": 1, "b": "x", "c": [1]}
+ // Invalid: {"d": 1} (unknown key), {"a": 1.1} (key 'a' is not int)
+ ["hash", {"keys": {"a": "int", "b": "str*", "c": ["array", "min_len", 1]}}]
+
+ // hash can contain a, b, c or other keys
+ // Valid: {"d": 1}, {"d": null}
+ // Invalid: {"a": 1.1} (key 'a' is not int)
+ ["hash", {"keys": {"a": "int", "b": "str*", "c": ["array", "min_len", 1]}, "keys.restrict": 0}]
+
+ // hash must contain keys a, b; can contain also c but no other keys
+ ["hash", {"req_keys": ["a","b"], "keys": {"a": "int", "b": "str*", "c": ["array", "min_len", 1]}}]
+
+ // hash must contain keys a, b; can contain c or other keys
+ ["hash", {"req_keys": ["a","b"], "keys": {"a": "int", "b": "str*", "c": ["array", "min_len", 1]}, "keys.restrict": 0}]
+
 =head2 Clause attribute
 
 =head2 Coercion rule
